@@ -375,16 +375,18 @@ var TabbrowserSessionManager = {
 	overlayStartupAction : function(aArgumentIsDefaultStartup)
 	{
 try {
-		var nav                 = this.service.browserWindows;
-		var forceToRestore      = this.service.getPref('browser.tabs.extensions.startup_action_overlay.one_time');
-		var loadSelectedSession = this.service.getPref('browser.tabs.extensions.startup_action_overlay') == 1;
+		var nav  = this.service.browserWindows;
+		var info = {};
+
+		info.forceToRestore = this.service.getPref('browser.tabs.extensions.startup_action_overlay.one_time');
+		info.loadSelectedSession = this.service.getPref('browser.tabs.extensions.startup_action_overlay') == 1;
 
 		if (
 			(
 				this.shouldResutoreLastVisitedTabs ||
-				loadSelectedSession ||
+				info.loadSelectedSession ||
 				this.shouldBackupTabs ||
-				forceToRestore
+				info.forceToRestore
 			) &&
 			nav.length == 1 &&
 			nav[0] == window &&
@@ -396,20 +398,19 @@ try {
 			)
 			) {
 
-			var shouldRestoreBackup = this.checkShouldRestoreBackup();
+			info.shouldRestoreBackup = this.checkShouldRestoreBackup();
 
 			if (
 				this.shouldResutoreLastVisitedTabs ||
-				loadSelectedSession ||
-				shouldRestoreBackup ||
-				forceToRestore
+				info.loadSelectedSession ||
+				info.shouldRestoreBackup ||
+				info.forceToRestore
 				) {
-				var selected = this.service.getPref('browser.tabs.extensions.startup_action_overlay.selected_session');
-				var loadType = shouldRestoreBackup ? 'backup' :
-								loadSelectedSession ? 'selected' :
+				info.loadType = info.shouldRestoreBackup ? 'backup' :
+								info.loadSelectedSession ? 'selected' :
 								'history';
 
-				if (loadType == 'selected' &&
+				if (info.loadType == 'selected' &&
 					this.service.getPref('browser.tabs.extensions.startup_action_overlay.onece_per_day')) {
 					// if the last loading has already been done today, skip restoring
 					var yesterday = new Date();
@@ -421,73 +422,16 @@ try {
 						last.getTime() >= yesterday.getTime() &&
 						last.getDate() == (new Date()).getDate()
 						)
-						loadType = null;
+						info.loadType = null;
 				}
 
-				if (loadType) {
-					var TSM = this;
-					var count = 0;
-					function restore()
-					{
-						var loadData;
-						switch (loadType)
-						{
-							case 'backup':
-								loadData = TSM.tabsBackupRoot;
-								break;
-
-							case 'selected':
-								if (!TSM.storedTabSetsRoot.length)
-									TSM.storedTabSetsRoot.reset();
-
-								if (!TSM.storedTabSets.length ||
-									TSM.storedTabSets.length != TSM.storedTabSetsRoot.length)
-									TSM.initStoredTabSets();
-
-								if (selected in TSM.storedTabSets)
-									loadData = TSM.storedTabSets[selected];
-								break;
-
-							default:
-							case 'history':
-								if (!TSM.tabHistoryQuitRoot.length)
-									TSM.tabHistoryQuitRoot.reset();
-
-								loadData = (TSM.tabHistoryQuitRoot.length > 1 && !forceToRestore) ? TSM.tabHistoryQuitRoot : TSM.tabHistory ;
-								break;
-						}
-
-						if (loadData && !loadData.length) loadData.reset();
-						if (!loadData || !loadData.length && count < 10) {
-							count++;
-							// retry after successfully initialized
-							window.setTimeout(arguments.callee, 10);
-						}
-
-						var doneCorrectly = TSM.restoreAllTabs(loadData);
-						var b = TSM.service.browser;
-						if (
-							(
-								!shouldRestoreBackup &&
-								(
-									TSM.tabHistoryQuitRoot.length < 2 ||
-									forceToRestore
-								) &&
-								!TSM.tabHistory.length
-							) ||
-							(
-								TSM.service.getPref('browser.tabs.extensions.last_tab_closing') == 3 &&
-								b.mTabs.length == 1 &&
-								b.selectedTab.isReallyBlank
-							)
-							)
-							b.removeTabInternal(b.selectedTab, { preventUndo : true });
-					}
-					restore();
+				if (info.loadType) {
+					info.count = 0;
+					window.setTimeout(this.restoreTabsOnStartup, 1, info);
 				}
 			}
 
-			if (forceToRestore) {
+			if (info.forceToRestore) {
 				this.service.setPref('browser.tabs.extensions.startup_action_overlay.one_time', false);
 				this.service.setPref('browser.tabs.extensions.startup_action_overlay', this.service.getPref('browser.tabs.extensions.startup_action_overlay.one_time.backup'));
 			}
@@ -505,6 +449,67 @@ catch(e) {
 		alert('@TabbrowserSessionManager.overlayStartupAction()\n'+e);
 }
 	},
+	restoreTabsOnStartup : function(aInfo)
+	{
+		var TSM   = TabbrowserSessionManager;
+
+		var loadData;
+		switch (aInfo.loadType)
+		{
+			case 'backup':
+				loadData = TSM.tabsBackupRoot;
+				break;
+
+			case 'selected':
+				if (!TSM.storedTabSetsRoot.length)
+					TSM.storedTabSetsRoot.reset();
+
+				if (!TSM.storedTabSets.length ||
+					TSM.storedTabSets.length != TSM.storedTabSetsRoot.length)
+					TSM.initStoredTabSets();
+
+				var selected = TSM.service.getPref('browser.tabs.extensions.startup_action_overlay.selected_session');
+				if (selected in TSM.storedTabSets)
+					loadData = TSM.storedTabSets[selected];
+				break;
+
+			default:
+			case 'history':
+				if (!TSM.tabHistoryQuitRoot.length)
+					TSM.tabHistoryQuitRoot.reset();
+
+				loadData = (TSM.tabHistoryQuitRoot.length > 1 && !aInfo.forceToRestore) ? TSM.tabHistoryQuitRoot : TSM.tabHistory ;
+				break;
+		}
+
+		if (loadData && !loadData.length) loadData.reset();
+		if (!loadData || !loadData.length && aInfo.count < 10) {
+			aInfo.count++;
+			// retry after successfully initialized
+			window.setTimeout(arguments.callee, 10, aInfo);
+		}
+
+		var doneCorrectly = TSM.restoreAllTabs(loadData);
+		var b = TSM.service.browser;
+		if (
+			(
+				!aInfo.shouldRestoreBackup &&
+				(
+					TSM.tabHistoryQuitRoot.length < 2 ||
+					aInfo.forceToRestore
+				) &&
+				!TSM.tabHistory.length
+			) ||
+			(
+				TSM.service.getPref('browser.tabs.extensions.last_tab_closing') == 3 &&
+				b.mTabs.length == 1 &&
+				b.selectedTab.isReallyBlank
+			)
+			)
+			TSM.service.browser.removeTabInternal(b.selectedTab, { preventUndo : true });
+
+		delete aInfo;
+	},
 	
 	checkShouldRestoreBackup : function() 
 	{
@@ -1215,6 +1220,7 @@ try {
 			info,
 			shouldReload = this.service.getPref('browser.tabs.extensions.reload_restored_session');
 
+		b.setAttribute('tab-animation-disabled', true);
 		for (var i = 0; i < aDatabase.length; i++)
 		{
 try {
@@ -1234,7 +1240,8 @@ try {
 
 			if (aRemoveTab) {
 				try {
-					b.removeTabInternal(aRemoveTab, { preventUndo : true });
+					this.service.browser.removeTabInternal(aRemoveTab, { preventUndo : true });
+					delete aTab;
 				}
 				catch(e) {
 					// do nothing it the tab has been removed.
@@ -1271,10 +1278,20 @@ catch(ex) {
 		alert('@TabbrowserSessionManager.restoreAllTabsFrom()\n'+ex);
 }
 
+		if (this.service.getPref('browser.tabs.extensions.group.tree.simple_operation'))
+			window.setTimeout(this.collapseExpandWithDelay, 0, b.selectedTab);
+		else
+			b.removeAttribute('tab-animation-disabled');
+
 		if (errorOut.value) doneCorrectly = false;
 
 		return doneCorrectly;
 	},
+	collapseExpandWithDelay : function(aTab)
+	{
+		aTab.collapseOtherSubgroups(true);
+		aTab.mTabBrowser.removeAttribute('tab-animation-disabled');
+	},
    
 	// ^uZbVz_[̏ 
 	initStoredTabSets : function()
@@ -1555,6 +1572,10 @@ catch(ex) {
 
 		if (!info) return;
 
+
+		if (!this.service.getPref('browser.tabs.extensions.undo.apply_original_index'))
+			delete info.index;
+
 		var t      = this.service.browser.selectedTab;
 		var newTab = this.service.browser.addTabWithTabInfo(info);
 
