@@ -9,9 +9,9 @@ function getIcon()
 	return TabbrowserService.getIconForBookmark(gBookmarkURI);
 }
 
-function setIcon()
+function setIcon(aIcon)
 {
-	TabbrowserService.setIconForBookmark(gBookmarkURI);
+	TabbrowserService.setIconForBookmark(gBookmarkURI, aIcon);
 }
 
 function newCommit()
@@ -44,7 +44,7 @@ function newCommit()
 		}
 		catch(e) {
 		}
-		setIcon();
+		setIcon(node.value);
 	}
 
 	var retVal = __tabextensions__Commit();
@@ -54,16 +54,18 @@ function newCommit()
 
 	var w = TS.browserWindows;
 	var b;
+	var t;
 
 	var j;
 	var name = ('useFixedLabel' in gInfo && gInfo.useFixedLabel) ? TS.getNameForBookmark(gBookmarkID) : null ;
 	for (i in w)
 	{
 		b = w[i].TabbrowserService.browser;
-		for (j in b.mTabs)
-			if (b.mTabs[j].mTabInfo.bookmarkID == gBookmarkID) {
-				b.initTabWithTabInfo(b.mTabs[j], gInfo);
-				if (name) b.setFixedLabelFor(b.mTabs[j], name, gBookmarkURI);
+		t = b.mTabs;
+		for (j = 0; j < t.length; j++)
+			if (t[j].getAttribute('tab-bookmarkID') == gBookmarkID) {
+				b.initTabWithTabInfo(t[j], gInfo);
+				if (name) b.setFixedLabelFor(t[j], name, gBookmarkURI);
 			}
 	}
 
@@ -146,11 +148,14 @@ window.addEventListener(
 			extra1.setAttribute('label', TS.strbundle.GetStringFromName('bookmarksProperty_extra1button'));
 			extra1.setAttribute('oncommand', 'tabextensionsOpenExtraDialog();');
 
+			var extraContainer = document.createElement('box');
+			extraContainer.setAttribute('collapsed', true);
+			document.documentElement.appendChild(extraContainer);
+
 			var iconURI = document.createElement('textbox');
 			iconURI.setAttribute('id', 'IconURI');
-			iconURI.setAttribute('hidden', true);
 			iconURI.setAttribute('value', getIcon());
-			document.documentElement.appendChild(iconURI);
+			extraContainer.appendChild(iconURI);
 		}
 
 	},
