@@ -1,5 +1,4 @@
 // Tabbrowser Extensions preferences
-pref("browser.tabs.extensions.use_another_binding", false);
 pref("browser.tabs.extensions.tab_menu.show", true);
 pref("browser.tabs.extensions.prevent_same_uri_tab", false);
 pref("browser.tabs.extensions.reuse_current_blank_tab", false);
@@ -36,7 +35,8 @@ pref("browser.tabs.extensions.tabbar_ondblclick", 1);
 pref("browser.tabs.extensions.tabbar_onmiddleclick", 113);
 pref("browser.tabs.extensions.tabbar_onrightclick", -1);
 pref("browser.tabs.extensions.focus_with_selected_order", false);
-pref("browser.tabs.extensions.show_progress", true);
+pref("browser.tabs.extensions.show_progress.tab",    true);
+pref("browser.tabs.extensions.show_progress.status", false);
 pref("browser.tabs.extensions.show_closebox.tab", 0);
 pref("browser.tabs.extensions.show_closebox.tab.delay", 500);
 pref("browser.tabs.extensions.show_closebox.tab.hide_delay", -1);
@@ -162,3 +162,5 @@ pref("browser.tabs.autoHide", false);
 pref("browser.tabs.extensions.use_multirow_rearrangable_tabs", false);
 pref("browser.tabs.extensions.undo_cache.global", 5);
 pref("browser.tabs.extensions.tabFlip",       true);
+pref("browser.tabs.extensions.back_to_ancestor",     false);
+pref("browser.tabs.extensions.forward_to_following", false);
