@@ -1,5 +1,4 @@
 // Tabbrowser Extensions preferences
-pref("browser.tabs.extensions.use_another_binding", false);
 pref("browser.tabs.extensions.tab_menu.show", true);
 pref("browser.tabs.extensions.prevent_same_uri_tab", true);
 pref("browser.tabs.extensions.reuse_current_blank_tab", true);
@@ -36,7 +35,8 @@ pref("browser.tabs.extensions.tabbar_ondblclick", 1);
 pref("browser.tabs.extensions.tabbar_onmiddleclick", 113);
 pref("browser.tabs.extensions.tabbar_onrightclick", -1);
 pref("browser.tabs.extensions.focus_with_selected_order", false);
-pref("browser.tabs.extensions.show_progress", true);
+pref("browser.tabs.extensions.show_progress.tab",    true);
+pref("browser.tabs.extensions.show_progress.status", false);
 pref("browser.tabs.extensions.show_closebox.tab", 0);
 pref("browser.tabs.extensions.show_closebox.tab.delay", 500);
 pref("browser.tabs.extensions.show_closebox.tab.hide_delay", -1);
@@ -147,6 +147,7 @@ pref("browser.tabs.extensions.show_context.openAllLinksInGroup", true);
 pref("browser.tabs.extensions.show_context.bookmarkAllLinksAsGroup", true);
 pref("browser.tabs.extensions.show_context.bookmarkTabGroup", true);
 pref("browser.tabs.extensions.group.enabled", true);
+pref("browser.tabs.extensions.group.tree.enabled", false);
 pref("browser.tabs.extensions.group.auto_purge_root", false);
 pref("browser.tabs.extensions.group.auto_purge", false);
 pref("browser.tabs.extensions.group.auto_color", true);
@@ -164,3 +165,5 @@ pref("browser.tabs.extensions.startup_action_overlay", 0);
 pref("browser.tabs.extensions.highlight_unread",     true);
 pref("browser.tabs.extensions.highlight_unread.style", "italic");
 pref("browser.tabs.extensions.tabFlip",       true);
+pref("browser.tabs.extensions.back_to_ancestor",     true);
+pref("browser.tabs.extensions.forward_to_following", true);
