@@ -32,8 +32,6 @@ function init()
 
 	onListSelect();
 
-	document.getElementById('anotherbinding').checked = (navigator.platform.search(/mac/i) > -1);
-
 
 	var cancelButton = document.documentElement.getButton('cancel');
 
@@ -56,16 +54,21 @@ function accept()
 			TabbrowserService.setPref('browser.tabs.extensions.default.preset.backup', preset);
 	}
 
-	preset = gList.selectedItem.getAttribute('name');
+
+	if (document.getElementById('presetRadio').selectedItem == document.getElementById('fromList')) {
+		preset = gList.selectedItem.getAttribute('name');
+	}
+	else {
+		preset = '_import';
+		TabbrowserService.setPref('browser.tabs.extensions.default.import', document.getElementById('importFileURL').value);
+	}
+
 
 	if (preset != '_restore') {
 		TabbrowserService.setPref('browser.tabs.extensions.default.preset', '_recall');
 		TabbrowserService.setPref('browser.tabs.extensions.default.preset.shouldLoad', preset);
 	}
 
-	if (document.getElementById('anotherbinding').checked)
-		pref.setBoolPref('browser.tabs.extensions.use_another_binding.newvalue', true);
-
 	window.close();
 }
 
