@@ -17,6 +17,7 @@ var TBEBookmarksService =
 		// Bookmarks
 		window.OpenBookmarkURL = this.openBookmarkURL;
 		window.OpenBookmarkGroupFromResource = this.service.openBookmarkGroup;
+		window.__tabextensions__addBookmarkForTabBrowser = window.addBookmarkForTabBrowser;
 		window.addBookmarkForTabBrowser = this.addBookmarkForTabBrowser;
 		if ('BookmarksUtils' in window) {
 			BookmarksUtils.__tabextensions__addBookmark = BookmarksUtils.addBookmark;
@@ -498,8 +499,14 @@ var TBEBookmarksService =
 		}
 	},
   
-	addBookmarkForTabBrowser : function(aTabBrowser, aSelect) 
+	addBookmarkForTabBrowser : function(aTabBrowser, aBookmarkAllTabs, aSelect) 
 	{
+		// for Firefox 1.0.x or before
+		if (!window.__tabextensions__addBookmarkForTabBrowser ||
+			window.__tabextensions__addBookmarkForTabBrowser.arity == 2) {
+			aSelect = aBookmarkAllTabs;
+		}
+
 		var info = [];
 		var currentInfo;
 
@@ -526,7 +533,8 @@ var TBEBookmarksService =
 			if (tabs[i] == aTabBrowser.selectedTab)
 				currentInfo = info[i];
 		}
-		if (!TabbrowserService.isNewTypeBrowser)
+
+		if (!TabbrowserService.isNewTypeBrowser) // Suite
 			window.openDialog(
 				'chrome://communicator/content/bookmarks/addBookmark.xul',
 				'',
@@ -538,7 +546,31 @@ var TBEBookmarksService =
 				'addGroup' + (aSelect ? ',group' : ''),
 				info
 			);
-		else
+		else if ('getDescriptionFromDocument' in BookmarksUtils) { // Firefox 1.1 or later
+			var dialogArgs = currentInfo;
+			try {
+				if ( // Firefox 1.5 or later
+					aBookmarkAllTabs &&
+					gNavigatorBundle.getString('bookmarkAllTabsDefault') &&
+					BROWSER_ADD_BM_FEATURES
+					) {
+					dialogArgs = {
+						name             : gNavigatorBundle.getString('bookmarkAllTabsDefault'),
+						bBookmarkAllTabs : true
+					};
+				}
+			}
+			catch(e) {
+			}
+			dialogArgs.objGroup = info;
+			window.openDialog(
+				'chrome://browser/content/bookmarks/addBookmark2.xul',
+				'',
+				BROWSER_ADD_BM_FEATURES,
+				dialogArgs
+			);
+		}
+		else // Firefox 1.0.x
 			window.openDialog(
 				'chrome://browser/content/bookmarks/addBookmark2.xul',
 				'',
