@@ -512,6 +512,7 @@ var TBEBrowserService =
 		var TS = TabbrowserService;
 
 		var id = aRelatedTab.tabId;
+//		if (!TS.browser.getTabByTabId(id)) return;
 
 		if (aWindow == Components.lookupMethod(aWindow, 'top').call(aWindow) &&
 			!('__tabextensions__initialized' in aWindow)) {
@@ -636,9 +637,12 @@ var TBEBrowserService =
 		}
 		else if (updateCurrentBrowser.indexOf('setFocus(element)') > -1) {
 			eval('b.updateCurrentBrowser = '+
-				updateCurrentBrowser.replace(
+				updateCurrentBrowser.replace( // old
 					/Components.lookupMethod\(element, "focus"\).call\(element\);/g,
 					'tabBrowser.setFocusInternal(element);'
+				).replace( // new
+					/element.focus\(\);/g,
+					'tabBrowser.setFocusInternal(element);'
 				).replace(
 					/^[^\(]*/,
 					'function'
@@ -669,7 +673,6 @@ var TBEBrowserService =
 
 
 
-
 		/* Tab Bar Splitter */
 
 		var splitter = document.createElement('splitter');
@@ -1782,6 +1785,18 @@ try{
 		}
 
 		aTabBrowser.mTabContainerInnerBox.setAttribute('tabs-scrollbox', true);
+
+		// SeaMonkey
+		var styleRule = aTabBrowser.mTabContainerInnerBox.getAttribute('style');
+		if (styleRule.indexOf('-moz-hidden-unscrollable') > -1) {
+			aTabBrowser.mTabContainerInnerBox.setAttribute('style', styleRule.replace(/overflow[^\;]+/, '')+'overflow:visible');
+			window.setTimeout([
+				"var box = gBrowser.mTabContainerInnerBox;",
+				"var styleRule = box.getAttribute('style');",
+				"box.setAttribute('style', styleRule.replace(/overflow[^\\;]+/, '')+'overflow:auto');"
+			].join(''), 1);
+		}
+
 		closeBox.setAttribute('tabs-scrollbox-right', true);
 }
 catch(e) {
