@@ -166,7 +166,8 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 			if (b.mTabs[i].getAttribute('tab-loadingURI') != aLinkInfo.uri)
 				continue;
 
-			this.service.popupAlert(this.service.strbundle.GetStringFromName('status_same_uri_tab_exists'));
+			if (this.service.getPref('browser.tabs.extensions.prevent_same_uri_tab.alert.show'))
+				this.service.popupAlert(this.service.strbundle.GetStringFromName('status_same_uri_tab_exists'));
 
 			if (!aLinkInfo.loadInBackground) {
 				b.selectedTab = b.mTabs[i];
@@ -290,9 +291,10 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 
 		// normal
 		aLinkInfo.newTabActionNormalClick = false;
-		aLinkInfo.normalClickAction = (
+		aLinkInfo.normalClickAction = !aLinkInfo.newTabActionMiddleClick &&
+			(
 				!aLinkInfo.browser ||
-				!tab ||
+//				!tab ||
 				!this.service.checkToLoadInCurrentTabOf(aLinkInfo.browser)
 			);
 		if (aLinkInfo.normalClickAction && aLinkInfo.behavior < 0) {
@@ -305,7 +307,7 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 		aLinkInfo.newTabActionBlockedURI = (aLinkInfo.newTabActionBlockedURI == 2) ||
 					(
 						aLinkInfo.newTabActionBlockedURI == 1 &&
-						!aLinkInfo.newTabActionNormalClick &&
+//						!aLinkInfo.newTabActionNormalClick &&
 						!aLinkInfo.newTabActionMiddleClick &&
 						aLinkInfo.behavior != 0
 					);
@@ -400,13 +402,16 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 		if (aLinkInfo.fieldNormalClicks &&
 			(!aLinkInfo.target || aLinkInfo.target == '_content')) {
 			if (nodeWrapper.getAttribute('onclick') ||
-				aLinkInfo.uri.substr(0, 11) == 'javascript:')
+				aLinkInfo.uri.substr(0, 11) == 'javascript:') {
+if (this.service.debug) dump('doLinkAction: Web Panel / blocked because it is javascript: link\n');
 				return true;
+			}
 
 			if (aLinkInfo.behavior == 0) {
 				this.service.stopEvent(aEvent);
 				aLinkInfo.loadFlags = Components.interfaces.nsIWebNavigation.LOAD_FLAGS_NONE;
 				this.service.loadLinkNormally(aLinkInfo);
+if (this.service.debug) dump('doLinkAction: Web Panel / load normally\n');
 				return true;
 			}
 		}
@@ -432,6 +437,7 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 				this.service.loadLinkNormally(aLinkInfo);
 				return true;
 			}
+if (this.service.debug) dump('doLinkAction: load in sidebar\n');
 			return __tabextensions__contentAreaClick(aEvent, aLinkInfo.fieldNormalClicks);
 		}
 
@@ -442,11 +448,12 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 		var topWin = Components.lookupMethod(aLinkInfo.window, 'top').call(aLinkInfo.window);
 
 
-		// in frames, ignore "open any link in new tab" feature for normal links.
+		// in frames, or in-page-link, ignore "open any link in new tab" feature for normal links.
 		if (
 			aLinkInfo.normalClickAction &&
 			aLinkInfo.newTabActionNormalClick &&
 			(
+				(uri.split('#')[0] == String(aLinkInfo.source).split('#')[0]) ||
 				(
 					!aLinkInfo.realTarget &&
 					topWin != aLinkInfo.window
@@ -457,11 +464,14 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 				)
 			)
 			) {
-			if (!aLinkInfo.referrerBlocked)
+			if (!aLinkInfo.referrerBlocked) {
+if (this.service.debug) dump('doLinkAction: in-page-link (referrer blocked)\n');
 				return __tabextensions__contentAreaClick(aEvent, aLinkInfo.fieldNormalClicks);
+			}
 
 			this.service.stopEvent(aEvent);
 			this.service.loadLinkNormally(aLinkInfo);
+if (this.service.debug) dump('doLinkAction: in-page-link\n');
 			return true;
 		}
 
@@ -541,6 +551,7 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 					b.attachTabTo(b.mTabs[i], b.selectedTab, true);
 
 				this.service.stopEvent(aEvent, true);
+if (this.service.debug) dump('doLinkAction: load in existing tab by target\n');
 				return false;
 			}
 		}
@@ -564,6 +575,7 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 
 			this.service.stopEvent(aEvent);
 
+if (this.service.debug) dump('doLinkAction: load normally\n');
 			return false;
 		}
 
@@ -666,6 +678,7 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 
 			this.service.markLinkVisited(uri, node);
 
+if (this.service.debug) dump('doLinkAction: open new tab\n');
 			return false;
 		}
 
@@ -676,6 +689,7 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 		this.service.fireEventForModules('DoLinkAction_postProcess', aLinkInfo);
 
 
+if (this.service.debug) dump('doLinkAction: do nothing\n');
 		return aLinkInfo.retVal;
 	},
   
