@@ -245,7 +245,8 @@ var TBEContextMenuService =
 			target,
 			targetURI,
 			parentTab;
-		var TS = TabbrowserService;
+		var TS   = TabbrowserService,
+			TCMS = TBEContextMenuService;
 
 		var root = TS.isNewTypeBrowser ? 'chrome://global/content/' : 'chrome://navigator/content/' ;
 
@@ -284,11 +285,11 @@ var TBEContextMenuService =
 
 				uri  = root+'viewSource.xul?url='+escape(doc.location);
 				args = [
-					doc.location,
+					String(doc.location),
 					'charset='+doc.characterSet,
 					cookie
 				];
-				onload    = 'onLoadViewSource();'
+				onload    = TCMS.onLoadViewSource;
 				target    = targetURI = doc.location;
 				parentTab = TS.browser.selectedTab;
 				break;
@@ -296,11 +297,11 @@ var TBEContextMenuService =
 			case 'uri':
 				uri  = root+'viewSource.xul?url='+escape(arguments[1]);
 				args = [
-					arguments[1],
+					String(arguments[1]),
 					arguments[2],
 					arguments[3]
 				];
-				onload    = 'onLoadViewSource();'
+				onload    = TCMS.onLoadViewSource;
 				target    = targetURI = arguments[1];
 				parentTab = null;
 				break;
@@ -345,7 +346,7 @@ var TBEContextMenuService =
 					reference,
 					context
 				];
-				onload    = 'onLoadViewPartialSource();'
+				onload    = TCMS.onLoadViewPartialSource;
 				target    = doc.location;
 				parentTab = TS.browser.selectedTab;
 				break;
@@ -361,11 +362,8 @@ var TBEContextMenuService =
 		var listener = function()
 			{
 				t.mBrowser.removeEventListener('load', listener, true);
-				t.mBrowser.contentDocument.documentElement.removeAttribute('onload');
-				t.mBrowser.contentWindow.onload = function() {};
 
-				t.mBrowser.contentWindow.arguments = args;
-				t.mBrowser.contentWindow.setTimeout(onload, 0);
+				onload(t.mBrowser.contentWindow, targetURI, args);
 
 				t.mBrowser.sessionHistory.QueryInterface(Components.interfaces.nsISHistoryInternal).replaceEntry(
 					0,
@@ -380,6 +378,25 @@ var TBEContextMenuService =
 						y                : 0
 					})
 				);
+
+				delete b;
+				delete t;
+				delete listener;
+
+				delete root;
+				delete label;
+
+				delete w;
+				delete winWrapper;
+				delete doc;
+				delete uri;
+				delete args;
+				delete onload;
+				delete target;
+				delete targetURI;
+				delete parentTab;
+				delete TS;
+				delete TCMS;
 			};
 		t.mBrowser.addEventListener('load', listener, true);
 
@@ -394,6 +411,84 @@ var TBEContextMenuService =
 
 		return true;
 	},
+	onLoadViewSource : function(aWindow, aLoadURL, aArgs)
+	{
+		var d = aWindow.document;
+		var b = d.getElementById('content');
+
+		var loadFromURL = true;
+		var arg;
+
+		arg = aArgs[1];
+		try {
+			if (typeof arg == 'string' &&
+				arg.indexOf('charset=') != -1) {
+				var arrayArgComponents = arg.split('=');
+				if (arrayArgComponents) {
+					b.markupDocumentViewer.defaultCharacterSet = arrayArgComponents[1];
+				}
+			}
+		}
+		catch (e) {
+		}
+
+		arg = aArgs[2];
+		try {
+			if (typeof arg == 'object' &&
+				arg != null) {
+				var PageLoader = b.webNavigation.QueryInterface(Components.interfaces.nsIWebPageDescriptor);
+				PageLoader.loadPage(arg, Components.interfaces.nsIWebPageDescriptor.DISPLAY_AS_SOURCE);
+				loadFromURL = false;
+			}
+		}
+		catch(e) {
+		}
+
+		if (loadFromURL) {
+			aLoadURL = 'view-source:' + aLoadURL;
+			b.setAttribute('src', aLoadURL);
+			try {
+				b.webNavigation.loadURI(aLoadURL, Components.interfaces.nsIWebNavigation.LOAD_FLAGS_NONE, null, null, null);
+			}
+			catch(e) {
+			}
+		}
+
+
+		var TS = TabbrowserService;
+		var node;
+
+		if ((node = d.getElementById('menu_wrapLongLines')) &&
+			TS.getPref('view_source.wrap_long_lines'))
+			node.setAttribute('checked', true);
+
+		if (node = d.getElementById('menu_highlightSyntax'))
+			node.setAttribute('checked', TS.getPref('view_source.syntax_highlight'));
+
+		aWindow._content.focus();
+	},
+	onLoadViewPartialSource : function(aWindow, aLoadURL, aArgs)
+	{
+		var d = aWindow.document;
+		var b = d.getElementById('content');
+
+
+		var TS = TabbrowserService;
+		var node;
+
+		if ((node = d.getElementById('menu_wrapLongLines')) &&
+			TS.getPref('view_source.wrap_long_lines'))
+			node.setAttribute('checked', true);
+
+		if (node = d.getElementById('menu_highlightSyntax'))
+			node.setAttribute('checked', TS.getPref('view_source.syntax_highlight'));
+
+
+		b.setAttribute('src', 'view-source:' + aLoadURL);
+
+
+		aWindow._content.focus();
+	},
  
 	getPartialSourceOf : function(aNode, aContext) // see viewPartialSource.js 
 	{
@@ -458,7 +553,7 @@ var TBEContextMenuService =
 
 		var TS = TabbrowserService;
 
-		var b = /*TS.popupNodeOwnerBrowser ||*/ TS.browser ;
+		var b = TS.getOwnerBrowserFromNode(document.popupNode) || TS.browser ;
 
 		var onLinks              = false,
 			onLinksWithoutMailto = false,
@@ -466,13 +561,21 @@ var TBEContextMenuService =
 			tab                  = null,
 			tabs                 = [];
 
+
+		var uri = this.link ?
+					(
+						'getLinkURI' in this ? this.linkURI.spec : // firefox 1.1 or later
+						this.linkURL() // firefox 1.0.x or before
+					) :
+					null ;
+
 		var showOpenInActiveTab = TS.getPref('browser.tabs.extensions.showNewActiveTabItem.links') && TS.getPref('browser.tabs.opentabfor.links.behavior') == 2;
 		var showOpenInThisTab = TS.getPref('browser.tabs.extensions.showThisTabItem.links') && (
 			TS.getPref('browser.tabs.opentabfor.links.behavior') > 0 ||
 			(
 				TS.getPref('browser.tabs.opentabfor.outerlink.level') > 0 &&
 				this.link &&
-				!TS.isSameHost(this.linkURL(), (new XPCNativeWrapper((new XPCNativeWrapper(this.link, 'ownerDocument')).ownerDocument, 'location')).location)
+				!TS.isSameHost(uri, (new XPCNativeWrapper((new XPCNativeWrapper(this.link, 'ownerDocument')).ownerDocument, 'location')).location)
 			) ||
 			(
 				(
@@ -505,10 +608,10 @@ var TBEContextMenuService =
 				isSingleWindow = TS.winHookMode == 2;
 
 				tab  = (b) ? b.selectedTab : null ;
-				if (tab) {
+				if (tab && tab.hasChildTabs) {
 					if (!tab.hasChildTabs() && tab.parentTab)
 						tab = tab.parentTab;
-					tabs = tab.allChildTabs;
+					tabs = tab.descendantTabs;
 					tabs.unshift(tab);
 				}
 			}
@@ -544,7 +647,7 @@ var TBEContextMenuService =
 		var TS = TabbrowserService;
 		if (!TS) return true;
 
-		var b = TS.browser; //TS.popupNodeOwnerBrowser;
+		var b = TS.getOwnerBrowserFromNode(document.popupNode);
 		if (!b || !b.isBlank) return true;
 
 		// popup a small menu instead of the normal
@@ -592,7 +695,11 @@ var TBEContextMenuService =
 		if (TabbrowserService.isBrowserWindow)
 			charsetArg = 'charset=' + (new XPCNativeWrapper(gBrowser.contentDocument, 'characterSet')).characterSet;
 
-		var referrer = aShouldSendReferrer && TabbrowserService.shouldSendReferrerWithLinkClick() ? getReferrer(document) : null;
+		var win = document.commandDispatcher.focusedWindow;
+		if (!win || (new XPCNativeWrapper(win, 'top')).top != gBrowser.contentWindow)
+			win = null;
+
+		var referrer = aShouldSendReferrer && TabbrowserService.shouldSendReferrerWithLinkClick() ? TabbrowserService.getReferrer(win) : null;
 		window.openDialog(TabbrowserService.browserURI, '_blank', 'chrome,all,dialog=no', aURI, charsetArg, referrer);
 
 		TabbrowserService.markLinkVisited(aURI, TabbrowserService.getLastActiveLink());
@@ -607,7 +714,11 @@ var TBEContextMenuService =
 		if (TabbrowserService.isBrowserWindow)
 			charsetArg = 'charset=' + (new XPCNativeWrapper(gBrowser.contentDocument, 'characterSet')).characterSet;
 
-		var referrer = TabbrowserService.shouldSendReferrerWithLinkClick() ? getReferrer(document) : null;
+		var win = document.commandDispatcher.focusedWindow;
+		if (!win || (new XPCNativeWrapper(win, 'top')).top != gBrowser.contentWindow)
+			win = null;
+
+		var referrer = TabbrowserService.shouldSendReferrerWithLinkClick() ? TabbrowserService.getReferrer(win) : null;
 		window.openDialog(TabbrowserService.browserURI, '_blank', 'chrome,all,dialog=no', aURI, charsetArg, referrer, aPostData);
 
 		TabbrowserService.markLinkVisited(aURI, aLinkNode);
