@@ -139,7 +139,8 @@ var TBELocationBarService =
 
 				t = b.mTabs[i];
 
-				TS.popupAlert(TS.strbundle.GetStringFromName('status_same_uri_tab_exists'));
+				if (TS.getPref('browser.tabs.extensions.prevent_same_uri_tab.alert.show'))
+					TS.popupAlert(TS.strbundle.GetStringFromName('status_same_uri_tab_exists'));
 
 				t.mBrowser.webNavigation.loadURI(
 					uri,
@@ -165,6 +166,14 @@ var TBELocationBarService =
 
 		if (!t) {
 			if (behavior > 0 && !b.selectedTab.isReallyBlank) {
+				try {
+					if ('handleURLBarRevert' in window)
+						handleURLBarRevert();
+					(new XPCNativeWrapper(content, 'focus()')).focus();
+				}
+				catch(e) {
+				}
+
 				if (!info) info = {};
 				if (aPostData)
 					info.postData = b.readPostStream(aPostData);
@@ -207,6 +216,16 @@ var TBELocationBarService =
  
 	SearchLoadURL : function(aURL, aTriggeringEvent) // for Firefox 1.0 or later 
 	{
+		if (!(aTriggeringEvent instanceof Event)) // Firefox 1.5 hands a boolean value as the second argument
+			aTriggeringEvent = {
+				type     : '',
+				target   : document.getElementById('searchbar'),
+				altKey   : (aTriggeringEvent ? true : false ),
+				shiftKey : false,
+				ctrlKey  : false,
+				metaKey  : false
+			};
+
 		return BrowserLoadURL(aTriggeringEvent, null, null, aURL);
 	},
  
