@@ -469,8 +469,12 @@ var TBEMiscOverlay =
 	{
 		var range = document.createRange();
 		range.selectNodeContents(aParent);
-		range.deleteContents();
-		range.detach();
+		var customItems = aParent.getElementsByAttribute('targetTab', '*');
+		if (customItems.length) {
+			range.setStartBefore(customItems[0].previousSibling || customItems[0]);
+			range.deleteContents();
+			range.detach();
+		}
 
 		__tabextensions__FillHistoryMenu(aParent, aMenu);
 
@@ -539,8 +543,10 @@ var TBEMiscOverlay =
 		__tabextensions__UpdateBackForwardButtons();
 
 
-		var backBroadcaster    = document.getElementById('Browser:Back');
-		var forwardBroadcaster = document.getElementById('Browser:Forward');
+		var backBroadcaster = document.getElementById('canGoBack') || // Suite
+								document.getElementById('Browser:Back'); // Firefox
+		var forwardBroadcaster = document.getElementById('canGoForward') || // Suite
+								document.getElementById('Browser:Forward'); // Firefox
 		var webNavigation      = gBrowser.webNavigation;
 
 
