@@ -327,8 +327,10 @@ var TBEMovableTabService =
 		var reversed = window.getComputedStyle(this.parentNode, null).direction != 'ltr';
 		var current = aEvent.target.tabIndex;
 
-		if (this.mScrollbar) // see "updateScrollbarFromEvent" in tabextensions.xml
-			coordValue -= Number(this.mScrollbar.getAttribute('curpos'));
+		if (this.mScrollbar) { // see "updateScrollbarFromEvent" in tabextensions.xml
+			var curPos = this.mGetScrollPosition(this.mScrollbar).curPos;
+			coordValue -= curPos;
+		}
 
 		var retVal;
 
